\name{grf}

\alias{grf}

%- Also NEED an `\alias' for EACH other topic documented here.

\title{Simulation of Gaussian Random Fields}

\description{
  Generates simulations of Gaussin random fields for given covariance parameters.
}


\usage{
grf(n, grid = "irreg", nx = round(sqrt(n)), ny = round(sqrt(n)), 
    nsim = 1, xlims = c(0, 1), ylims = c(0, 1), cov.model = c("exponential", 
    "matern", "gaussian", "spherical", "circular", "cubic", 
    "wave", "powered.exponential", "cauchy", "gneiting", 
    "gneiting.matern", "pure.nugget"),
    cov.pars = stop("covariance parameters (sigmasq and phi) needed"), 
    kappa = 0.5, nugget = 0, lambda = 1,
    method = c("cholesky", "svd", "eigen", "circular.embedding"),
    messages.screen = TRUE)
}

%- maybe also `usage' for other objects documented here.

\arguments{
  \item{n}{number of points (locations) in the simulations}
  \item{grid}{optional. A matrix \eqn{Nx2} with coordinates of the
    points}
  \item{nx}{optional. Number of points in the X direction.}
  \item{ny}{optional. Number of points in the X direction.}
  \item{nsim}{Number of simulations. Defeults to 1.}
  \item{xlims}{optional. Limits of the area in the X direction.}
  \item{ylims}{optional. Limits of the area in the Y direction.}
  \item{cov.model}{correlation finction. See \code{\link{cov.spatial}} for
    details on the available choices of correlation functions. Defaults
    to exponential model.}
  \item{cov.pars}{}
  \item{kappa}{additional parameter needed for some of the correlation
    functions: (\code{"matern", "powered.exponential", "gneiting"} and
    \code{"gneiting.matern"}). For more details see documentation for the
    function \code{\link{cov.spatial}}.}
  \item{nugget}{Nugget effect}
  \item{lambda}{Box-Cox transformation parameter. If \eqn{\lambda = 1}{lambda = 1} no
    transformation is done, otherwise the Box-Cox data transformation is
    done before the analysis.}
  \item{method}{simulation method. Defauts to Cholesky decomposition.}
  \item{messages.screen}{a flag \code{TRUE} or \code{FALSE} indicating
	whether or not messages are printend on the screen (or output file)
	while the function is running.}
  
}


\details{

}


\value{
  ~Describe the value returned
  If it is a LIST, use
  \item{comp1 }{Description of `comp1'}
  \item{comp2 }{Description of `comp2'}
  ...
}


\references{
  Further information about \code{geoR/geoS} can be found at:\cr
  \url{http://www.maths.lancs.ac.uk/~ribeiro/geoR.html}
}


\author{Paulo Justiniano Ribeiro Jr. \email{<paulojus@est.ufpr.br>} \cr
  Peter J. Diggle \email{<p.diggle@lancaster.ac.uk>}.
}


\seealso{\code{\link{plot.grf}}, \code{\link{image.grf}}.}

\examples{
sim1 <- grf(100, cov.pars=c(1, .25))
plot(sim1)
image.grf(sim1)
#
sim2 <- grf(10201, grid="reg", cov.pars=c(10, .2), met="circ")
image.grf(sim2)

}

\keyword{spatial}
